trident.backend package
=======================

Submodules
----------

trident.backend.common module
-----------------------------

.. automodule:: trident.backend.common
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.function\_tools module
--------------------------------------

.. automodule:: trident.backend.function_tools
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.iteration\_tools module
---------------------------------------

.. automodule:: trident.backend.iteration_tools
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.load\_backend module
------------------------------------

.. automodule:: trident.backend.load_backend
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.opencv\_backend module
--------------------------------------

.. automodule:: trident.backend.opencv_backend
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.optimizer module
--------------------------------

.. automodule:: trident.backend.optimizer
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.pillow\_backend module
--------------------------------------

.. automodule:: trident.backend.pillow_backend
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.pytorch\_backend module
---------------------------------------

.. automodule:: trident.backend.pytorch_backend
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.pytorch\_ops module
-----------------------------------

.. automodule:: trident.backend.pytorch_ops
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.tensorflow\_backend module
------------------------------------------

.. automodule:: trident.backend.tensorflow_backend
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.tensorflow\_ops module
--------------------------------------

.. automodule:: trident.backend.tensorflow_ops
   :members:
   :undoc-members:
   :show-inheritance:

trident.backend.tensorflow\_serialization module
------------------------------------------------

.. automodule:: trident.backend.tensorflow_serialization
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: trident.backend
   :members:
   :undoc-members:
   :show-inheritance:
